pycocoa.colors.CMYColor

Package pycocoa :: Module colors :: Class CMYColor |
[frames] | no frames]

# Class CMYColor

              object --+
                       |
    internals._Objectype --+
                           |
            baseTypes._Type0 --+
                               |
                           Color --+
                                   |
                                  CMYColor

Color in the Cyan-Magenta-Yellow space.

Instance Methods
Inherited from `Color`: `__init__`, `copy`, `toCMY3`, `toHSB3`, `toRGB3` Inherited from `baseTypes._Type0`: `__repr__`, `__str__`, `type2strepr` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| cyan Get the cyan component (`float`) or `None` if not applicable.
| magenta Get the magenta component (`float`) or `None` if not applicable.
| yellow Get the yellow component (`float`) or `None` if not applicable.
Inherited from `Color`: `alpha`, `black`, `blue`, `brightness`, `colorSpace`, `green`, `hex`, `hue`, `n`, `name`, `nsColor`, `red`, `saturation`, `white` Inherited from `baseTypes._Type0`: `NS`, `NSDelegate` Inherited from `internals._Objectype`: `typename` Inherited from `object`: `__class__`

Property Details

### cyan Get the cyan component (`float`) or `None` if not applicable. Get Method: cyan(self) - Get the cyan component (`float`) or `None` if not applicable. Set Method: Read_Only(inst, value) - Throws an `AttributeError`, always.

### magenta Get the magenta component (`float`) or `None` if not applicable. Get Method: magenta(self) - Get the magenta component (`float`) or `None` if not applicable. Set Method: Read_Only(inst, value) - Throws an `AttributeError`, always.

### yellow Get the yellow component (`float`) or `None` if not applicable. Get Method: yellow(self) - Get the yellow component (`float`) or `None` if not applicable. Set Method: Read_Only(inst, value) - Throws an `AttributeError`, always.